@@ -1,14 +1,14 @@
-#' Deprecated functions
+#' Deprecated functions and objects
 #'
-#' These functions should no longer be used. They will be removed in a
-#' future release of \code{infer}.
+#' These functions and objects should no longer be used. They will be removed 
+#' in a future release of \code{infer}.
 #' @param x See the non-deprecated function.
 #' @param level See the non-deprecated function.
 #' @param type See the non-deprecated function.
 #' @param point_estimate See the non-deprecated function.
 #' @param obs_stat See the non-deprecated function.
 #' @param direction See the non-deprecated function.
-#' @seealso \code{\link{get_p_value}}, \code{\link{get_confidence_interval}}
+#' @seealso [get_p_value()], [get_confidence_interval()], [generate()]
 #' @name deprecated
 NULL
 
@@ -31,3 +31,7 @@ p_value <- function(x, obs_stat, direction) {
   get_p_value(x = x, obs_stat = obs_stat, direction = direction)
 }
 
+#' @rdname deprecated
+#' @export
+GENERATION_TYPES <- c("bootstrap", "permute",  "simulate")
+
