@@ -1,7 +1,6 @@
 #' Specify response and explanatory variables
 #'
 #' @description
-#' \Sexpr[results=rd, stage=render]{lifecycle::badge("maturing")}
 #'  
 #' `specify()` is used to specify which columns in the supplied data frame are
 #' the relevant response (and, if applicable, explanatory) variables. Note that 
@@ -38,7 +37,9 @@
 #'   specify(response = age, explanatory = partyid)
 #'
 #' # More in-depth explanation of how to use the infer package
+#' \dontrun{
 #' vignette("infer")
+#' }
 #'
 #' @importFrom rlang f_lhs
 #' @importFrom rlang f_rhs
@@ -136,9 +137,6 @@ specify <- function(x, formula, response = NULL,
 #' @importFrom rlang get_expr
 parse_variables <- function(x, formula, response = NULL,
                             explanatory = NULL) {
-  if (!methods::hasArg(formula) && !methods::hasArg(response)) {
-    stop_glue("Please give the `response` variable.")
-  }
   if (methods::hasArg(formula)) {
     tryCatch(
       rlang::is_formula(formula), 
@@ -165,7 +163,7 @@ parse_variables <- function(x, formula, response = NULL,
   
   # Check response and explanatory variables to be appropriate for later use
   if (!has_response(x)) {
-    stop_glue("Supply not `NULL` response variable.")
+    stop_glue("Please supply a response variable that is not `NULL`.")
   }
   check_var_correct(x, "response")
   check_var_correct(x, "explanatory")
