@@ -1,11 +1,12 @@
 context("aliases")
 
 test_that("aliases work", {
-  expect_gt(
-    iris_calc %>%
+  expect_equal(
+    gss_calc %>%
       get_pvalue(obs_stat = -0.2, direction = "right") %>%
       dplyr::pull(),
-    expected = 0.98
+    expected = 1,
+    tolerance = eps
   )
   
   expect_silent(test_df %>% get_ci())
@@ -13,10 +14,10 @@ test_that("aliases work", {
 
 test_that("old aliases produce warning", {
   expect_warning(
-    iris_calc %>%
+    gss_calc %>%
       p_value(obs_stat = -0.2, direction = "right") %>%
       dplyr::pull(),
-    expected = 0.98
+    expected = 1
   )
   
   expect_warning(test_df %>% conf_int())
